from setuptools import setup, find_packages

setup(
    name = 'frasht',
    version = '0.0.1',
    keywords='ds caa',
    description = 'A library that makes Python development easier',
    license = 'MIT License',
    url = 'https://github.com/',
    author = 'Frasht',
    author_email = '3357099132@qq.com',
    packages = find_packages(),
    platforms = 'any',
    install_requires = [],
)